@@ -6,7 +6,7 @@ from discrete_fuzzy_operators.base.operators.unary_operators.fuzzy_discrete_unar
 from typing import Callable
 
 
-class DiscreteFuzzyNegation(FuzzyDiscreteUnaryOperator):
+class DiscreteNegation(FuzzyDiscreteUnaryOperator):
 
     def __init__(self, n: int,
                  operator_vector: numpy.array = None,
@@ -20,7 +20,7 @@ class DiscreteFuzzyNegation(FuzzyDiscreteUnaryOperator):
             operator_vector: A list of integers, representing the operator in its vector expression.
             operator_expression: A function, representing the analytical expression.
         """
-        super(DiscreteFuzzyNegation, self).__init__(n, operator_vector, operator_expression)
+        super(DiscreteNegation, self).__init__(n, operator_vector, operator_expression)
 
         if not self.is_negation():
             warnings.warn("With the input arguments, the generated operator is not a discrete negation since it is "
